@@ -10,11 +10,11 @@ from multidict._multidict_py import MultiDict as PyMultiDict  # noqa: E402
 from multidict._multidict_py import MultiDictProxy as PyMultiDictProxy
 
 if USE_CYTHON:
-    from multidict._multidict import (
-        MultiDict,
+    from multidict._multidict import (  # type: ignore
         CIMultiDict,
-        MultiDictProxy,
         CIMultiDictProxy,
+        MultiDict,
+        MultiDictProxy,
     )
 
 
